@@ -292,11 +292,12 @@ pub fn run_solve(matches: &ArgMatches) {
                                 .with_max_time(max_time)
                                 .with_cost_variation(cost_variation)
                                 .with_telemetry(telemetry)
+                                .with_offspring(Some(num_cpus::get()), None, None, None)
                                 .with_seed(seed)
                         };
 
                         let (solution, _, metrics) = builder
-                            .with_solutions(solution.map_or_else(Vec::new, |s| vec![s]))
+                            .with_init_solutions(solution.map_or_else(Vec::new, |s| vec![s]))
                             .build()
                             .and_then(|solver| solver.solve())
                             .unwrap_or_else(|err| {
